@@ -55,15 +55,14 @@ const _notTrailingJunk = '[^\\s`!()\\[\\]{};:\'\\".,<>?\u00AB\u00BB\u201C\u201D\
 // a lot of false positives, so whitelist some useful ones and hope nobody complains :-)
 const _schemeWhitelist = ['geo', 'mailto', 'man', 'info', 'ghelp', 'help'];
 
-/* eslint-disable prefer-template */
 const _urlRegexp = new RegExp(
-    '(^|' + _leadingJunk + ')' +
+    `(^|${_leadingJunk})` +
     '(' +
         '(?:' +
             '(?:[a-z]+)://' +                     // scheme://
             '|' +
             '(?:' +
-                _schemeWhitelist.join('|') +      // scheme:
+               `${_schemeWhitelist.join('|')}` + // scheme:
             '):' +
             '|' +
             'www\\d{0,3}[.]' +                    // www.
@@ -73,21 +72,20 @@ const _urlRegexp = new RegExp(
         '(?:' +                                   // one or more:
             '[^\\s()<>]+' +                       // run of non-space non-()
             '|' +                                 // or
-            _balancedParens +                     // balanced parens
+            `${_balancedParens}` +                // balanced parens
         ')+' +
         '(?:' +                                   // end with:
-            _balancedParens +                     // balanced parens
+            `${_balancedParens}` +                // balanced parens
             '|' +                                 // or
-            _notTrailingJunk +                    // last non-junk char
+            `${_notTrailingJunk}` +               // last non-junk char
         ')' +
     ')', 'gi');
-/* eslint-enable prefer-template */
 
 const _channelRegexp = new RegExp('(^| )#([\\w\\+\\.-]+)', 'g');
 
-let _gpasteExpire = undefined;
+let _gpasteExpire;
 
-let _inFlatpakSandbox = undefined;
+let _inFlatpakSandbox;
 
 function isFlatpakSandbox() {
     if (_inFlatpakSandbox === undefined)
@@ -96,10 +94,10 @@ function isFlatpakSandbox() {
 }
 
 function getTpEventTime() {
-    let time = Gtk.get_current_event_time ();
-    if (time == 0)
+    let time = Gtk.get_current_event_time();
+    if (time === 0)
         return GLib.MAXUINT32;
-    return Tp.user_action_time_from_x11 (time);
+    return Tp.user_action_time_from_x11(time);
 }
 
 function storeAccountPassword(account, password, callback) {
@@ -121,7 +119,7 @@ function _storePassword(schema, label, account, password, callback) {
             callback(success);
         } catch (e) {
             let name = account.display_name;
-            log(`Failed to store password for account "${name}": ${e.message}`);
+            log(`Failed to store password for account ${name}: ${e.message}`);
             callback(false);
         }
     });
@@ -170,7 +168,7 @@ function findChannels(str, server) {
         res.push({
             url: `irc://${server}/${match[2]}`,
             name: `#${match[2]}`,
-            pos: match.index + match[1].length
+            pos: match.index + match[1].length,
         });
     }
     return res;
@@ -180,9 +178,9 @@ function openURL(url, timestamp) {
     let app = Gio.Application.get_default();
     try {
         if (app.active_window)
-            Gtk.show_uri_on_window (app.active_window, url, timestamp);
+            Gtk.show_uri_on_window(app.active_window, url, timestamp);
         else
-            Gtk.show_uri (Gdk.Screen.get_default(), url, timestamp);
+            Gtk.show_uri(Gdk.Screen.get_default(), url, timestamp);
     } catch (e) {
         let n = new AppNotifications.SimpleOutput(_('Failed to open link'));
         app.notificationQueue.addNotification(n);
@@ -194,12 +192,12 @@ function updateTerms(terms, str) {
     let normalized = str.trim().toLowerCase().replace(/\s+/g, ' ');
     let newTerms = normalized ? normalized.split(' ') : [];
 
-    let changed = newTerms.length != terms.length;
+    let changed = newTerms.length !== terms.length;
     for (let i = 0; i < terms.length && !changed; i++)
-        changed = terms[i] != newTerms[i];
+        changed = terms[i] !== newTerms[i];
 
     if (changed)
-        terms.splice.apply(terms, [0, terms.length, ...newTerms]);
+        terms.splice(0, terms.length, ...newTerms);
 
     return changed;
 }
@@ -208,8 +206,8 @@ function _getGpasteExpire(callback) {
     let session = new Soup.Session();
     let paramUrl = `${GPASTE_BASEURL}api/json/parameter/expire`;
     let message = Soup.form_request_new_from_hash('GET', paramUrl, {});
-    session.queue_message(message, (s, message) => {
-        if (message.status_code != Soup.KnownStatusCode.OK) {
+    session.queue_message(message, () => {
+        if (message.status_code !== Soup.KnownStatusCode.OK) {
             callback(false);
             return;
         }
@@ -234,7 +232,7 @@ function _getGpasteExpire(callback) {
 }
 
 function gpaste(text, title, callback) {
-    if (_gpasteExpire == undefined) {
+    if (_gpasteExpire === undefined) {
         _getGpasteExpire(success => {
             if (success)
                 gpaste(text, title, callback);
@@ -248,17 +246,17 @@ function gpaste(text, title, callback) {
         title = `${title.substr(0, MAX_PASTE_TITLE_LENGTH - 1)}…`;
 
     let params = {
-        title: title,
+        title,
         data: text,
         expire: _gpasteExpire,
-        language: 'text'
+        language: 'text',
     };
 
     let session = new Soup.Session();
     let createUrl = `${GPASTE_BASEURL}api/json/create`;
     let message = Soup.form_request_new_from_hash('POST', createUrl, params);
-    session.queue_message(message, (s, message) => {
-        if (message.status_code != Soup.KnownStatusCode.OK) {
+    session.queue_message(message, () => {
+        if (message.status_code !== Soup.KnownStatusCode.OK) {
             callback(null);
             return;
         }
@@ -284,8 +282,8 @@ function imgurPaste(pixbuf, title, callback) {
     }
 
     let params = {
-        title: title,
-        image: GLib.base64_encode(buffer)
+        title,
+        image: GLib.base64_encode(buffer),
     };
 
     let session = new Soup.Session();
@@ -294,8 +292,8 @@ function imgurPaste(pixbuf, title, callback) {
 
     let requestHeaders = message.request_headers;
     requestHeaders.append('Authorization', `Client-ID ${IMGUR_CLIENT_ID}`);
-    session.queue_message(message, (s, message) => {
-        if (message.status_code != Soup.KnownStatusCode.OK) {
+    session.queue_message(message, () => {
+        if (message.status_code !== Soup.KnownStatusCode.OK) {
             callback(null);
             return;
         }
